*************
Release Notes
*************


Version 0.2
-----------

This release contains a number of bug fixes and improvements.

Contributors
^^^^^^^^^^^^
- Axel Donath
- Karthik Reddy

Pull Requests
^^^^^^^^^^^^^

- Add LIRASignificanceEstimator [#57]
- Fix random seed handling [#59]
- Add trace animation [#60]
- Add and run pre-commit hooks [#61]
- Add Chandra example data [#62]
- Add signifiance estimator to point source tutorial [#63] 